netutil

package
v0.0.0-...-01ed203 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 23, 2025 License: Apache-2.0 Imports: 21 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var Dialer = &net.Dialer{
	Timeout:   30 * time.Second,
	KeepAlive: 30 * time.Second,
	DualStack: TCP6Enabled(),
}

Dialer is default network dialer.

var Resolver resolver

Resolver is default DNS resolver.

Functions

func DialMaybeSRV

func DialMaybeSRV(ctx context.Context, network, addr string) (net.Conn, error)

DialMaybeSRV dials the given addr.

The addr may be either the usual TCP address or srv+host form, where host is SRV addr. If the addr has srv+host form, then the host is resolved with SRV into randomly chosen TCP address for the connection.

func GetServerTLSConfig

func GetServerTLSConfig(tlsCertFile, tlsKeyFile, tlsMinVersion string, tlsCipherSuites []string) (*tls.Config, error)

GetServerTLSConfig returns TLS config for the server.

func GetTCPNetwork

func GetTCPNetwork() string

GetTCPNetwork returns current tcp network.

func GetUDPNetwork

func GetUDPNetwork() string

GetUDPNetwork returns current udp network.

func IsTrivialNetworkError

func IsTrivialNetworkError(err error) bool

IsTrivialNetworkError returns true if the err can be ignored during logging.

func NewStatDialFunc

func NewStatDialFunc(metricPrefix string) func(ctx context.Context, network, addr string) (net.Conn, error)

NewStatDialFunc returns dialer function that supports DNS SRV records and registers stats metrics for conns.

func NewStatDialFuncWithDial

func NewStatDialFuncWithDial(metricPrefix string, dialFunc func(ctx context.Context, network, addr string) (net.Conn, error)) func(ctx context.Context, network, addr string) (net.Conn, error)

NewStatDialFuncWithDial returns dialer function that registers stats metrics for conns.

func ParseGroupAddr

func ParseGroupAddr(addr string) (string, string)

ParseGroupAddr parses `groupID/addrX` addr and returns (groupID, addrX).

If addr doesn't contain `groupID/` prefix, then ("", addr) is returned.

func ParseTLSVersion

func ParseTLSVersion(s string) (uint16, error)

ParseTLSVersion returns tls version from the given string s.

func TCP6Enabled

func TCP6Enabled() bool

TCP6Enabled returns true if dialing and listening for IPv4 TCP is enabled.

Types

type ConnPool

type ConnPool struct {
	// contains filtered or unexported fields
}

ConnPool is a connection pool with ZSTD-compressed connections.

func NewConnPool

func NewConnPool(ms *metrics.Set, name, addr string, handshakeFunc handshake.Func, compressionLevel int, dialTimeout, userTimeout time.Duration) *ConnPool

NewConnPool creates a new connection pool for the given addr.

Name is used in metrics registered at ms. handshakeFunc is used for handshaking after the connection establishing. The compression is disabled if compressionLevel <= 0.

Call ConnPool.MustStop when the returned ConnPool is no longer needed.

func (*ConnPool) Addr

func (cp *ConnPool) Addr() string

Addr returns the address where connections are established.

func (*ConnPool) Get

func (cp *ConnPool) Get() (*handshake.BufferedConn, error)

Get returns free connection from the pool.

func (*ConnPool) MustStop

func (cp *ConnPool) MustStop()

MustStop frees up resources occupied by cp.

ConnPool.Get() immediately returns an error after MustStop call. ConnPool.Put() immediately closes the connection returned to the pool.

func (*ConnPool) Put

func (cp *ConnPool) Put(bc *handshake.BufferedConn)

Put puts bc back to the pool.

Do not put broken and closed connections to the pool!

type TCPDialer

type TCPDialer struct {
	// contains filtered or unexported fields
}

TCPDialer is used for dialing the addr passed to NewTCPDialer.

It also gathers various stats for dialed connections.

func NewTCPDialer

func NewTCPDialer(ms *metrics.Set, name, addr string, dialTimeout, userTimeout time.Duration) *TCPDialer

NewTCPDialer returns new dialer for dialing the given addr.

The name is used in metric tags for the returned dialer. The name must be unique among dialers.

func (*TCPDialer) Addr

func (d *TCPDialer) Addr() string

Addr returns the address the dialer dials to.

func (*TCPDialer) Dial

func (d *TCPDialer) Dial() (net.Conn, error)

Dial dials the addr passed to NewTCPDialer.

type TCPListener

type TCPListener struct {
	net.Listener
	// contains filtered or unexported fields
}

TCPListener listens for the addr passed to NewTCPListener.

It also gathers various stats for the accepted connections.

func NewTCPListener

func NewTCPListener(name, addr string, useProxyProtocol bool, tlsConfig *tls.Config) (*TCPListener, error)

NewTCPListener returns new TCP listener for the given addr and optional tlsConfig.

name is used for metrics. Each listener in the program must have a distinct name.

If useProxyProtocol is set to true, then the returned listener accepts TCP connections via proxy protocol. See https://www.haproxy.org/download/1.8/doc/proxy-protocol.txt

func (*TCPListener) Accept

func (ln *TCPListener) Accept() (net.Conn, error)

Accept accepts connections from the addr passed to NewTCPListener.

Jump to